@@ -1,20 +1,10 @@
 # The COPYRIGHT file at the top level of this repository contains the full
 # copyright notices and license terms.
-import logging
-
-from trytond.exceptions import UserError
 from trytond.i18n import gettext
 from trytond.model import fields
+from trytond.model.exceptions import RequiredValidationError
 from trytond.pool import PoolMeta
 
-HAS_VATNUMBER = False
-try:
-    import vatnumber
-    HAS_VATNUMBER = True
-except ImportError:
-    logging.getLogger(__name__).warning(
-            'Unable to import vatnumber. VAT number validation disabled.')
-
 
 class TaxTemplate(metaclass=PoolMeta):
     __name__ = 'account.tax.template'
@@ -38,12 +28,12 @@ class TaxTemplate(metaclass=PoolMeta):
         taxes = self.search([
                 ('vat_code_required', '!=', self.vat_code_required),
                 ['OR',
-                    ('id' , 'in', [t.id for t in self.childs]),
+                    ('id', 'in', [t.id for t in self.childs]),
                     ('parent', '=', self.id)
                     ],
                 ])
         if taxes:
-            raise UserError(gettext(
+            raise RequiredValidationError(gettext(
                     'account_tax_recapitulative_statement.'
                     'same_vat_code_required',
                     first=self.rec_name, second=taxes[0].rec_name,))
@@ -58,14 +48,9 @@ class Tax(metaclass=PoolMeta):
 class Line(metaclass=PoolMeta):
     __name__ = 'account.tax.line'
 
-    vat_code = fields.Char('VAT Code',
-            # TODO: Add tax.vat_code_required as function field
-            # #states={
-            #'required': Eval('tax.vat_code_required') == Bool(True),
-            #    }
-            )
+    vat_code = fields.Char('VAT Code')
 
-    @fields.depends('tax', 'move_line')
+    @fields.depends('tax', 'move_line', '_parent_move_line.id')
     def on_change_tax(self):
         try:
             super().on_change_tax()
@@ -87,7 +72,7 @@ class Line(metaclass=PoolMeta):
 
     def check_vat_code(self):
         if self.tax.vat_code_required and not self.vat_code:
-            raise UserError(gettext(
+            raise RequiredValidationError(gettext(
                     'account_tax_recapitulative_statement.'
                     'missing_line_vat_code',
                     line=self.id))
@@ -102,11 +87,11 @@ class Line(metaclass=PoolMeta):
             if line.tax:
                 if line.tax.vat_code_required and not line.vat_code:
                     if not line.move_line.party:
-                        raise UserError(gettext(
+                        raise RequiredValidationError(gettext(
                                 'account_tax_recapitulative_statement.'
                                 'missing_party_move_line'))
                     if not line.move_line.party.tax_identifier:
-                        raise UserError(gettext(
+                        raise RequiredValidationError(gettext(
                                 'account_tax_recapitulative_statement.'
                                 'missing_party_vat_code',
                                 party=line.move_line.party.rec_name))
