@@ -2,7 +2,8 @@
 # the full copyright notices and license terms.
 
 try:
-    from trytond.modules.account_tax_recapitulative_statement.tests.test_account_tax_recapitulative_statement import suite
+    from trytond.modules.account_tax_recapitulative_statement.tests.test_account_tax_recapitulative_statement import (
+        suite)
 except ImportError:
     from .test_account_tax_recapitulative_statement import suite
 
